@@ -14,7 +14,7 @@ class Abstract(object):
   '''Webapp abastract class'''
   def __init__(self, cfg):
     protocol = 'https' if cfg.get('ssl', True) else 'http'
-    self.endpoint = protocol + '://' + cfg.get('host') + cfg.get('prefix')
+    self.endpoint = "{}://{}{}".format(protocol, cfg.get('host'), cfg.get('prefix'))
     self.payload = {
       'username': cfg.get('username'),
       'api_key': cfg.get('key')
@@ -29,7 +29,7 @@ class Abstract(object):
         params=self.payload,
         verify=verify
       )
-      return self._parse_response(response)
+      return self._parse_obj_response(response, obj_id)
     except requests.exceptions.RequestException as error:
       eprint('ERROR: {}'.format(error))
       return {'error': True, 'msg': error}
@@ -47,7 +47,7 @@ class Abstract(object):
         params=params,
         verify=verify,
       )
-      parsed = self._parse_response(response)
+      parsed = self._parse_obj_response(response, obj_id)
 
       # save in cache if required
       Abstract._save_cache(cache, parsed)
@@ -96,11 +96,16 @@ class Abstract(object):
       offset += limit
     return item_list
 
+  def resource_uri(self, obj_id):
+    '''Generate resource uri from obj id'''
+    path = self.endpoint.replace(self.host, '')
+    return '{}{}'.format(path, obj_id)
+
   def resource_url(self, obj_id):
     '''Generate resource uri from obj id'''
     return '{}{}'.format(self.endpoint, obj_id)
 
-  def save(self, obj_id=None, params={}, payload={}, verify=True): # pylint: disable=dangerous-default-value
+  def save(self, obj_id=None, params={}, payload={}, verify=True, datatype=None): # pylint: disable=dangerous-default-value
     '''Save or update resource'''
     params.update(self.payload)
     try:
@@ -111,7 +116,9 @@ class Abstract(object):
         params=params,
         verify=verify,
       )
-      return self._parse_response(response)
+      if datatype == 'analysis' or datatype == 'sample':
+        return self._parse_validated_response(response, obj_id)
+      return self._parse_obj_response(response, obj_id)
     except requests.exceptions.RequestException as error:
       eprint('ERROR: {}'.format(error))
       return {'error': True, 'msg': error}
@@ -125,6 +132,78 @@ class Abstract(object):
         return json.loads(open(filename, 'r').read().strip())
     return None
 
+  @classmethod
+  def _parse_obj_response(cls, response, obj_id):
+    '''General response parser with obj id'''
+    error_msgs = {
+      401: 'You don\'t have access to resource with id {}.'.format(obj_id) if obj_id else 'You don\'t have access to this resource.',
+      404: 'Resource with id {} not found.'.format(obj_id) if obj_id else 'Resource not found.',
+      500: 'Error retrieving data from API!'
+    }
+    if response.status_code in error_msgs:
+      eprint('ERROR: {}'.format(error_msgs[response.status_code]))
+      return {'error': True, 'msg': error_msgs[response.status_code]}
+
+    if response.status_code == 204:  # for delete response
+      return {'error': False}
+
+    try:
+      response = response.json()
+
+      error = isinstance(response, dict) and response.get('error')
+      if error:
+        if isinstance(error, dict):
+          response = error
+
+          if response.get('error_msgs'):
+            eprint('ERROR: {}'.format(response['error_msgs']))
+
+          if response.get('warning_msgs'):
+            eprint('WARNING: {}'.format(response['warning_msgs']))
+        else:
+          eprint('ERROR: {}'.format(error))
+
+      return response
+    except json.decoder.JSONDecodeError as error:
+      msg = 'ERROR: Not able to parse response: {}.'.format(error)
+      eprint(msg)
+      return {'error': True, 'msg': msg}
+
+  @classmethod
+  def _parse_validated_response(cls, response, obj_id):
+    '''General response parser with obj id'''
+    error_msgs = {
+      401: 'You don\'t have access to resource with id {}.'.format(obj_id) if obj_id else 'You don\'t have access to this resource.',
+      500: 'Error retrieving data from API!'
+    }
+    if response.status_code in error_msgs:
+      eprint('ERROR: {}'.format(error_msgs[response.status_code]))
+      return {'error': True, 'msg': error_msgs[response.status_code]}
+
+    if response.status_code == 204:  # for delete response
+      return {'error': False}
+
+    try:
+      response = response.json()
+      error = isinstance(response, dict) and response.get('error')
+      if error:
+        if isinstance(error, dict):
+          response = error
+
+          if response.get('error_msgs'):
+            eprint('ERROR: {}'.format(response['error_msgs']))
+
+          if response.get('warning_msgs'):
+            eprint('WARNING: {}'.format(response['warning_msgs']))
+        else:
+          eprint('ERROR: {}'.format(error))
+
+      return response
+    except json.decoder.JSONDecodeError as error:
+      msg = 'ERROR: Not able to parse response: {}.'.format(error)
+      eprint(msg)
+      return {'error': True, 'msg': msg}
+
   @classmethod
   def _parse_response(cls, response):
     '''General response parser'''
